# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.test_run_iteration_information import TestRunIterationInformation

class TestTestRunIterationInformation(unittest.TestCase):
    """TestRunIterationInformation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestRunIterationInformation:
        """Test TestRunIterationInformation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestRunIterationInformation`
        """
        model = TestRunIterationInformation()
        if include_optional:
            return TestRunIterationInformation(
                id = 135,
                test_run_id = 83,
                status = 'FAIL',
                color = '#D45D52',
                parameters = [
                    openapi_client.models.dataset_parameter.DatasetParameter(
                        name = '', 
                        value = '', )
                    ],
                steps = [
                    openapi_client.models.iteration_step_information.IterationStepInformation(
                        index = 1, 
                        fields = {"Action":{"type":"Wiki","value":{"raw":"When prompted to login I fill the username field with John and the password with 12345","rendered":"<p>When prompted to login I fill the username field with John and the password with 12345</p>"}},"Expected Result":{"type":"Wiki","value":{"raw":"I'm authenticated!","rendered":"<p>I'm authenticated!</p>"}}}, )
                    ]
            )
        else:
            return TestRunIterationInformation(
        )
        """

    def testTestRunIterationInformation(self):
        """Test TestRunIterationInformation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.update_test_run_examples import UpdateTestRunExamples

class TestUpdateTestRunExamples(unittest.TestCase):
    """UpdateTestRunExamples unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateTestRunExamples:
        """Test UpdateTestRunExamples
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateTestRunExamples`
        """
        model = UpdateTestRunExamples()
        if include_optional:
            return UpdateTestRunExamples(
                id = '1379',
                rank = 1,
                values = ["value1","value2"],
                status = 'TODO',
                status_description = 'Description of the status',
                duration = '12960',
                backgrounds = [
                    openapi_client.models.test_example_step_bean.TestExampleStepBean(
                        id = 1, 
                        rank = 1, 
                        type = 'type', 
                        keyword = 'Example Keyword', 
                        name = 'Example Name', 
                        duration = '14226', 
                        log_error = '', 
                        status = 'PASS', )
                    ],
                hooks = [
                    openapi_client.models.test_example_step_bean.TestExampleStepBean(
                        id = 1, 
                        rank = 1, 
                        type = 'type', 
                        keyword = 'Example Keyword', 
                        name = 'Example Name', 
                        duration = '14226', 
                        log_error = '', 
                        status = 'PASS', )
                    ],
                steps = [
                    openapi_client.models.test_example_step_bean.TestExampleStepBean(
                        id = 1, 
                        rank = 1, 
                        type = 'type', 
                        keyword = 'Example Keyword', 
                        name = 'Example Name', 
                        duration = '14226', 
                        log_error = '', 
                        status = 'PASS', )
                    ]
            )
        else:
            return UpdateTestRunExamples(
        )
        """

    def testUpdateTestRunExamples(self):
        """Test UpdateTestRunExamples"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.test_definition_one_of import TestDefinitionOneOf

class TestTestDefinitionOneOf(unittest.TestCase):
    """TestDefinitionOneOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestDefinitionOneOf:
        """Test TestDefinitionOneOf
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestDefinitionOneOf`
        """
        model = TestDefinitionOneOf()
        if include_optional:
            return TestDefinitionOneOf(
                steps = [
                    openapi_client.models.test_definition_one_of_steps_inner.Test_definition_oneOf_steps_inner(
                        id = 56, 
                        index = 56, 
                        step = openapi_client.models.test_definition_one_of_steps_inner_step.Test_definition_oneOf_steps_inner_step(
                            raw = '', 
                            rendered = '', ), 
                        data = openapi_client.models.test_definition_one_of_steps_inner_step.Test_definition_oneOf_steps_inner_step(
                            raw = '', 
                            rendered = '', ), 
                        result = , 
                        attachements = [
                            ''
                            ], )
                    ]
            )
        else:
            return TestDefinitionOneOf(
        )
        """

    def testTestDefinitionOneOf(self):
        """Test TestDefinitionOneOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from openapi_client.models.update_test_run_custom_fields_inner import UpdateTestRunCustomFieldsInner
from openapi_client.models.xray_json_import_execution_tests_inner_evidences_inner import XrayJsonImportExecutionTestsInnerEvidencesInner
from openapi_client.models.xray_json_import_execution_tests_inner_results_inner import XrayJsonImportExecutionTestsInnerResultsInner
from openapi_client.models.xray_json_import_execution_tests_inner_steps_inner import XrayJsonImportExecutionTestsInnerStepsInner
from openapi_client.models.xray_json_import_execution_tests_inner_test_info import XrayJsonImportExecutionTestsInnerTestInfo
from typing import Optional, Set
from typing_extensions import Self

class XrayJsonImportExecutionTestsInner(BaseModel):
    """
    XrayJsonImportExecutionTestsInner
    """ # noqa: E501
    comment: Optional[StrictStr] = None
    finish: Optional[StrictStr] = None
    start: Optional[StrictStr] = None
    status: Optional[StrictStr] = None
    test_version: Optional[StrictStr] = Field(default=None, alias="testVersion")
    custom_fields: Optional[List[UpdateTestRunCustomFieldsInner]] = Field(default=None, alias="customFields")
    test_info: Optional[XrayJsonImportExecutionTestsInnerTestInfo] = Field(default=None, alias="testInfo")
    test_key: Optional[StrictStr] = Field(default=None, alias="testKey")
    executed_by: Optional[StrictStr] = Field(default=None, alias="executedBy")
    evidences: Optional[List[XrayJsonImportExecutionTestsInnerEvidencesInner]] = None
    results: Optional[List[XrayJsonImportExecutionTestsInnerResultsInner]] = None
    examples: Optional[List[StrictStr]] = None
    steps: Optional[List[XrayJsonImportExecutionTestsInnerStepsInner]] = None
    __properties: ClassVar[List[str]] = ["comment", "finish", "start", "status", "testVersion", "customFields", "testInfo", "testKey", "executedBy", "evidences", "results", "examples", "steps"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of XrayJsonImportExecutionTestsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in custom_fields (list)
        _items = []
        if self.custom_fields:
            for _item_custom_fields in self.custom_fields:
                if _item_custom_fields:
                    _items.append(_item_custom_fields.to_dict())
            _dict['customFields'] = _items
        # override the default output from pydantic by calling `to_dict()` of test_info
        if self.test_info:
            _dict['testInfo'] = self.test_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in evidences (list)
        _items = []
        if self.evidences:
            for _item_evidences in self.evidences:
                if _item_evidences:
                    _items.append(_item_evidences.to_dict())
            _dict['evidences'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in results (list)
        _items = []
        if self.results:
            for _item_results in self.results:
                if _item_results:
                    _items.append(_item_results.to_dict())
            _dict['results'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in steps (list)
        _items = []
        if self.steps:
            for _item_steps in self.steps:
                if _item_steps:
                    _items.append(_item_steps.to_dict())
            _dict['steps'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of XrayJsonImportExecutionTestsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "comment": obj.get("comment"),
            "finish": obj.get("finish"),
            "start": obj.get("start"),
            "status": obj.get("status"),
            "testVersion": obj.get("testVersion"),
            "customFields": [UpdateTestRunCustomFieldsInner.from_dict(_item) for _item in obj["customFields"]] if obj.get("customFields") is not None else None,
            "testInfo": XrayJsonImportExecutionTestsInnerTestInfo.from_dict(obj["testInfo"]) if obj.get("testInfo") is not None else None,
            "testKey": obj.get("testKey"),
            "executedBy": obj.get("executedBy"),
            "evidences": [XrayJsonImportExecutionTestsInnerEvidencesInner.from_dict(_item) for _item in obj["evidences"]] if obj.get("evidences") is not None else None,
            "results": [XrayJsonImportExecutionTestsInnerResultsInner.from_dict(_item) for _item in obj["results"]] if obj.get("results") is not None else None,
            "examples": obj.get("examples"),
            "steps": [XrayJsonImportExecutionTestsInnerStepsInner.from_dict(_item) for _item in obj["steps"]] if obj.get("steps") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import List
from typing_extensions import Annotated
from openapi_client.models.create_step_request_body import CreateStepRequestBody
from openapi_client.models.create_step_response import CreateStepResponse
from openapi_client.models.file_response import FileResponse
from openapi_client.models.step_response import StepResponse
from openapi_client.models.test_steps_response import TestStepsResponse
from openapi_client.models.update_step_request_body import UpdateStepRequestBody

from openapi_client.api_client import ApiClient, RequestSerialized
from openapi_client.api_response import ApiResponse
from openapi_client.rest import RESTResponseType


class TestStepApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def call_10_api_test_test_key_step_put(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        create_step_request_body: CreateStepRequestBody,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CreateStepResponse:
        """call_10_api_test_test_key_step_put

        Create a new test step. All step fields values are listed under _fields_ and identified by the name and a list of attachments to add to the step. The field values should follow a certain format according to the custom field type. <br /><br /> - **Toggle Fields** values should be _\"true\"_, _\"false\"_, _\"0\"_ or _\"1\"_ <br /><br /> - **Number Fields** values should be a string containing a number, e.g. _\"320\"_. Decimal Number are also accepted,for instance, \"320.5\". The decimal places are always separated by a _\".\"_ <br /> <br /> - **Single Select and Radio Button Fields** values should be a single string containing the option value, e.g. _\"Option A\"_. The value should be a valid option for that custom field. The values are not case sensitive. <br /><br /> - **Multiple Select Fields** values should be an array of the string of option values, e.g. _[\"Option A\", \"Option B\"]_. All the selected values should be valid for that custom field. The option values are not case sensitive. <br /><br /> - **Date Fields** should follow the ISO format _yyyy-MM-dd_, where _yyyy_ represents the year, _MM_ the month in year and _dd_ the day in the month. For instance, a valid value would be _\"2020-05-02\"_. <br /><br /> - **Date Time fields** should be in UTC following the ISO format _yyyy-MM-dd'T'HH:mm'Z'_. The date part follows the same date format, while _HH_ represents the hours (0-24), _mm_ the minutes in hour and _Z_ indicates the hour in UTC. For instance, a valid date time value would be _\"2020-05-02T10:30Z\"_. <br /><br /> The remaining field types values do not required a specific validation. For instance, for a Single Line Custom field a valid value would be _\"Perform Action B\"_. <br /><br /> If some value is not valid for a certain custom field type, an error will be return stating the field with the incorrect value. Furthermore, **all required step fields must be provided**.

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param create_step_request_body: (required)
        :type create_step_request_body: CreateStepRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_step_put_serialize(
            test_key=test_key,
            create_step_request_body=create_step_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CreateStepResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_test_test_key_step_put_with_http_info(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        create_step_request_body: CreateStepRequestBody,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CreateStepResponse]:
        """call_10_api_test_test_key_step_put

        Create a new test step. All step fields values are listed under _fields_ and identified by the name and a list of attachments to add to the step. The field values should follow a certain format according to the custom field type. <br /><br /> - **Toggle Fields** values should be _\"true\"_, _\"false\"_, _\"0\"_ or _\"1\"_ <br /><br /> - **Number Fields** values should be a string containing a number, e.g. _\"320\"_. Decimal Number are also accepted,for instance, \"320.5\". The decimal places are always separated by a _\".\"_ <br /> <br /> - **Single Select and Radio Button Fields** values should be a single string containing the option value, e.g. _\"Option A\"_. The value should be a valid option for that custom field. The values are not case sensitive. <br /><br /> - **Multiple Select Fields** values should be an array of the string of option values, e.g. _[\"Option A\", \"Option B\"]_. All the selected values should be valid for that custom field. The option values are not case sensitive. <br /><br /> - **Date Fields** should follow the ISO format _yyyy-MM-dd_, where _yyyy_ represents the year, _MM_ the month in year and _dd_ the day in the month. For instance, a valid value would be _\"2020-05-02\"_. <br /><br /> - **Date Time fields** should be in UTC following the ISO format _yyyy-MM-dd'T'HH:mm'Z'_. The date part follows the same date format, while _HH_ represents the hours (0-24), _mm_ the minutes in hour and _Z_ indicates the hour in UTC. For instance, a valid date time value would be _\"2020-05-02T10:30Z\"_. <br /><br /> The remaining field types values do not required a specific validation. For instance, for a Single Line Custom field a valid value would be _\"Perform Action B\"_. <br /><br /> If some value is not valid for a certain custom field type, an error will be return stating the field with the incorrect value. Furthermore, **all required step fields must be provided**.

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param create_step_request_body: (required)
        :type create_step_request_body: CreateStepRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_step_put_serialize(
            test_key=test_key,
            create_step_request_body=create_step_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CreateStepResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_test_test_key_step_put_without_preload_content(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        create_step_request_body: CreateStepRequestBody,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_test_test_key_step_put

        Create a new test step. All step fields values are listed under _fields_ and identified by the name and a list of attachments to add to the step. The field values should follow a certain format according to the custom field type. <br /><br /> - **Toggle Fields** values should be _\"true\"_, _\"false\"_, _\"0\"_ or _\"1\"_ <br /><br /> - **Number Fields** values should be a string containing a number, e.g. _\"320\"_. Decimal Number are also accepted,for instance, \"320.5\". The decimal places are always separated by a _\".\"_ <br /> <br /> - **Single Select and Radio Button Fields** values should be a single string containing the option value, e.g. _\"Option A\"_. The value should be a valid option for that custom field. The values are not case sensitive. <br /><br /> - **Multiple Select Fields** values should be an array of the string of option values, e.g. _[\"Option A\", \"Option B\"]_. All the selected values should be valid for that custom field. The option values are not case sensitive. <br /><br /> - **Date Fields** should follow the ISO format _yyyy-MM-dd_, where _yyyy_ represents the year, _MM_ the month in year and _dd_ the day in the month. For instance, a valid value would be _\"2020-05-02\"_. <br /><br /> - **Date Time fields** should be in UTC following the ISO format _yyyy-MM-dd'T'HH:mm'Z'_. The date part follows the same date format, while _HH_ represents the hours (0-24), _mm_ the minutes in hour and _Z_ indicates the hour in UTC. For instance, a valid date time value would be _\"2020-05-02T10:30Z\"_. <br /><br /> The remaining field types values do not required a specific validation. For instance, for a Single Line Custom field a valid value would be _\"Perform Action B\"_. <br /><br /> If some value is not valid for a certain custom field type, an error will be return stating the field with the incorrect value. Furthermore, **all required step fields must be provided**.

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param create_step_request_body: (required)
        :type create_step_request_body: CreateStepRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_step_put_serialize(
            test_key=test_key,
            create_step_request_body=create_step_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CreateStepResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_test_test_key_step_put_serialize(
        self,
        test_key,
        create_step_request_body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if test_key is not None:
            _path_params['testKey'] = test_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_step_request_body is not None:
            _body_params = create_step_request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/1.0/api/test/{testKey}/step',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def call_10_api_test_test_key_steps_get(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TestStepsResponse:
        """call_10_api_test_test_key_steps_get

        Returns all the steps of a test issue given the key. The response contains for each step the corresponding id, index, fields and the attachments. <br /> <br /> The Test Step fields are identified by their name and can be of type _Data_ (Toggle, Number, Date and Date Time fields), _Option_ (Single Select, Multiple Select and Radio Button fields), _Wiki_ (Native fields, Single and Multiple Line fields). <br /> <br /> The value of step fields of type _Wiki_ have a raw and rendered value. _Option_ fields value will be an array containing the information of the selected options (the option id and its value).

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_get_serialize(
            test_key=test_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestStepsResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_test_test_key_steps_get_with_http_info(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TestStepsResponse]:
        """call_10_api_test_test_key_steps_get

        Returns all the steps of a test issue given the key. The response contains for each step the corresponding id, index, fields and the attachments. <br /> <br /> The Test Step fields are identified by their name and can be of type _Data_ (Toggle, Number, Date and Date Time fields), _Option_ (Single Select, Multiple Select and Radio Button fields), _Wiki_ (Native fields, Single and Multiple Line fields). <br /> <br /> The value of step fields of type _Wiki_ have a raw and rendered value. _Option_ fields value will be an array containing the information of the selected options (the option id and its value).

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_get_serialize(
            test_key=test_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestStepsResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_test_test_key_steps_get_without_preload_content(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_test_test_key_steps_get

        Returns all the steps of a test issue given the key. The response contains for each step the corresponding id, index, fields and the attachments. <br /> <br /> The Test Step fields are identified by their name and can be of type _Data_ (Toggle, Number, Date and Date Time fields), _Option_ (Single Select, Multiple Select and Radio Button fields), _Wiki_ (Native fields, Single and Multiple Line fields). <br /> <br /> The value of step fields of type _Wiki_ have a raw and rendered value. _Option_ fields value will be an array containing the information of the selected options (the option id and its value).

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_get_serialize(
            test_key=test_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestStepsResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_test_test_key_steps_get_serialize(
        self,
        test_key,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if test_key is not None:
            _path_params['testKey'] = test_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/1.0/api/test/{testKey}/steps',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete(
        self,
        test_key: Annotated[StrictStr, Field(description="Test with key CALC-123 does not exist or is not a manual test.")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        attachment_id: Annotated[StrictInt, Field(description="The id of the attachment")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete

        Deletes a test step attachment, given the test key and step and attachment ids.

        :param test_key: Test with key CALC-123 does not exist or is not a manual test. (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param attachment_id: The id of the attachment (required)
        :type attachment_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete_serialize(
            test_key=test_key,
            step_id=step_id,
            attachment_id=attachment_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete_with_http_info(
        self,
        test_key: Annotated[StrictStr, Field(description="Test with key CALC-123 does not exist or is not a manual test.")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        attachment_id: Annotated[StrictInt, Field(description="The id of the attachment")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete

        Deletes a test step attachment, given the test key and step and attachment ids.

        :param test_key: Test with key CALC-123 does not exist or is not a manual test. (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param attachment_id: The id of the attachment (required)
        :type attachment_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete_serialize(
            test_key=test_key,
            step_id=step_id,
            attachment_id=attachment_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete_without_preload_content(
        self,
        test_key: Annotated[StrictStr, Field(description="Test with key CALC-123 does not exist or is not a manual test.")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        attachment_id: Annotated[StrictInt, Field(description="The id of the attachment")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete

        Deletes a test step attachment, given the test key and step and attachment ids.

        :param test_key: Test with key CALC-123 does not exist or is not a manual test. (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param attachment_id: The id of the attachment (required)
        :type attachment_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete_serialize(
            test_key=test_key,
            step_id=step_id,
            attachment_id=attachment_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete_serialize(
        self,
        test_key,
        step_id,
        attachment_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if test_key is not None:
            _path_params['testKey'] = test_key
        if step_id is not None:
            _path_params['stepId'] = step_id
        if attachment_id is not None:
            _path_params['attachmentId'] = attachment_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/1.0/api/test/{testKey}/steps/{stepId}/attachment/{attachmentId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def call_10_api_test_test_key_steps_step_id_attachments_get(
        self,
        test_key: Annotated[StrictStr, Field(description="Test with key CALC-123 does not exist or is not a manual test.")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[FileResponse]:
        """call_10_api_test_test_key_steps_step_id_attachments_get

        Returns all the attachments of a test step, given the test key and step id.

        :param test_key: Test with key CALC-123 does not exist or is not a manual test. (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_attachments_get_serialize(
            test_key=test_key,
            step_id=step_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[FileResponse]",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_test_test_key_steps_step_id_attachments_get_with_http_info(
        self,
        test_key: Annotated[StrictStr, Field(description="Test with key CALC-123 does not exist or is not a manual test.")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[FileResponse]]:
        """call_10_api_test_test_key_steps_step_id_attachments_get

        Returns all the attachments of a test step, given the test key and step id.

        :param test_key: Test with key CALC-123 does not exist or is not a manual test. (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_attachments_get_serialize(
            test_key=test_key,
            step_id=step_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[FileResponse]",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_test_test_key_steps_step_id_attachments_get_without_preload_content(
        self,
        test_key: Annotated[StrictStr, Field(description="Test with key CALC-123 does not exist or is not a manual test.")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_test_test_key_steps_step_id_attachments_get

        Returns all the attachments of a test step, given the test key and step id.

        :param test_key: Test with key CALC-123 does not exist or is not a manual test. (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_attachments_get_serialize(
            test_key=test_key,
            step_id=step_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[FileResponse]",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_test_test_key_steps_step_id_attachments_get_serialize(
        self,
        test_key,
        step_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if test_key is not None:
            _path_params['testKey'] = test_key
        if step_id is not None:
            _path_params['stepId'] = step_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/1.0/api/test/{testKey}/steps/{stepId}/attachments',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def call_10_api_test_test_key_steps_step_id_delete(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """call_10_api_test_test_key_steps_step_id_delete

        Deletes a test step given the test key and the step id.

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_delete_serialize(
            test_key=test_key,
            step_id=step_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_test_test_key_steps_step_id_delete_with_http_info(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """call_10_api_test_test_key_steps_step_id_delete

        Deletes a test step given the test key and the step id.

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_delete_serialize(
            test_key=test_key,
            step_id=step_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_test_test_key_steps_step_id_delete_without_preload_content(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_test_test_key_steps_step_id_delete

        Deletes a test step given the test key and the step id.

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_delete_serialize(
            test_key=test_key,
            step_id=step_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_test_test_key_steps_step_id_delete_serialize(
        self,
        test_key,
        step_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if test_key is not None:
            _path_params['testKey'] = test_key
        if step_id is not None:
            _path_params['stepId'] = step_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/1.0/api/test/{testKey}/steps/{stepId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def call_10_api_test_test_key_steps_step_id_get(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> StepResponse:
        """call_10_api_test_test_key_steps_step_id_get

        Returns the values of a single test step, given the test key and the step id. The response follows the same format as the previous endpoints, containing the step id, index, fields and the attachments. <br /> <br /> The Test Step fields are identified by their name and can be of type _Data_ (Toggle, Number, Date and Date Time fields), _Option_ (Single Select, Multiple Select and Radio Button fields), _Wiki_ (Native fields, Single and Multiple Line fields). <br /> <br /> The value of step fields of type _Wiki_ have a raw and rendered value. _Option_ fields value will be an array containing the information of the selected options (the option id and its value).

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_get_serialize(
            test_key=test_key,
            step_id=step_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StepResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_test_test_key_steps_step_id_get_with_http_info(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[StepResponse]:
        """call_10_api_test_test_key_steps_step_id_get

        Returns the values of a single test step, given the test key and the step id. The response follows the same format as the previous endpoints, containing the step id, index, fields and the attachments. <br /> <br /> The Test Step fields are identified by their name and can be of type _Data_ (Toggle, Number, Date and Date Time fields), _Option_ (Single Select, Multiple Select and Radio Button fields), _Wiki_ (Native fields, Single and Multiple Line fields). <br /> <br /> The value of step fields of type _Wiki_ have a raw and rendered value. _Option_ fields value will be an array containing the information of the selected options (the option id and its value).

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_get_serialize(
            test_key=test_key,
            step_id=step_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StepResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_test_test_key_steps_step_id_get_without_preload_content(
        self,
        test_key: Annotated[StrictStr, Field(description="The key of the test issue, e.g., CALC-562")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_test_test_key_steps_step_id_get

        Returns the values of a single test step, given the test key and the step id. The response follows the same format as the previous endpoints, containing the step id, index, fields and the attachments. <br /> <br /> The Test Step fields are identified by their name and can be of type _Data_ (Toggle, Number, Date and Date Time fields), _Option_ (Single Select, Multiple Select and Radio Button fields), _Wiki_ (Native fields, Single and Multiple Line fields). <br /> <br /> The value of step fields of type _Wiki_ have a raw and rendered value. _Option_ fields value will be an array containing the information of the selected options (the option id and its value).

        :param test_key: The key of the test issue, e.g., CALC-562 (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_get_serialize(
            test_key=test_key,
            step_id=step_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StepResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_test_test_key_steps_step_id_get_serialize(
        self,
        test_key,
        step_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if test_key is not None:
            _path_params['testKey'] = test_key
        if step_id is not None:
            _path_params['stepId'] = step_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/1.0/api/test/{testKey}/steps/{stepId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def call_10_api_test_test_key_steps_step_id_put(
        self,
        test_key: Annotated[StrictStr, Field(description="Test Key")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        update_step_request_body: UpdateStepRequestBody,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CreateStepResponse:
        """call_10_api_test_test_key_steps_step_id_put

        Updates the values of an existing test step, given the test key and step id. The user can update the field values and the attachments of a step. The values should follow a specific format similar to the step creation. <br/><br/> - **Toggle Fields** values should be _\"true\"_, _\"false\"_, _\"0\"_ or _\"1\"_ <br /><br /> - **Number Fields** values should be a string containing a number, e.g. _\"320\"_. Decimal Number are also accepted,for instance, \"320.5\". The decimal places are always separated by a _\".\"_ <br /> <br /> - **Single Select and Radio Button Fields** values should be a single string containing the option value, e.g. _\"Option A\"_. The value should be a valid option for that custom field. The values are not case sensitive. <br /><br /> - **Multiple Select Fields** values should be an array of the string of option values, e.g. _[\"Option A\", \"Option B\"]_. All the selected values should be valid for that custom field. The option values are not case sensitive. <br /><br /> - **Date Fields** should follow the ISO format _yyyy-MM-dd_, where _yyyy_ represents the year, _MM_ the month in year and _dd_ the day in the month. For instance, a valid value would be _\"2020-05-02\"_. <br /><br /> - **Date Time fields** should be in UTC following the ISO format _yyyy-MM-dd'T'HH:mm'Z'_. The date part follows the same date format, while _HH_ represents the hours (0-24), _mm_ the minutes in hour and _Z_ indicates the hour in UTC. For instance, a valid date time value would be _\"2020-05-02T10:30Z\"_. <br /><br /> The remaining field types values do not required a specific validation. For instance, for a Single Line Custom field a valid value would be _\"Perform Action B\"_. <br /><br /> If some value is not valid for a certain custom field type, an error will be return stating the field with the incorrect value. A field value can be deleted sending an empty value, such as _\"\"_ or _[]_, or by sending _null_. **It is not possible to delete the value of a required field.**

        :param test_key: Test Key (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param update_step_request_body: (required)
        :type update_step_request_body: UpdateStepRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_put_serialize(
            test_key=test_key,
            step_id=step_id,
            update_step_request_body=update_step_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateStepResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_test_test_key_steps_step_id_put_with_http_info(
        self,
        test_key: Annotated[StrictStr, Field(description="Test Key")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        update_step_request_body: UpdateStepRequestBody,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CreateStepResponse]:
        """call_10_api_test_test_key_steps_step_id_put

        Updates the values of an existing test step, given the test key and step id. The user can update the field values and the attachments of a step. The values should follow a specific format similar to the step creation. <br/><br/> - **Toggle Fields** values should be _\"true\"_, _\"false\"_, _\"0\"_ or _\"1\"_ <br /><br /> - **Number Fields** values should be a string containing a number, e.g. _\"320\"_. Decimal Number are also accepted,for instance, \"320.5\". The decimal places are always separated by a _\".\"_ <br /> <br /> - **Single Select and Radio Button Fields** values should be a single string containing the option value, e.g. _\"Option A\"_. The value should be a valid option for that custom field. The values are not case sensitive. <br /><br /> - **Multiple Select Fields** values should be an array of the string of option values, e.g. _[\"Option A\", \"Option B\"]_. All the selected values should be valid for that custom field. The option values are not case sensitive. <br /><br /> - **Date Fields** should follow the ISO format _yyyy-MM-dd_, where _yyyy_ represents the year, _MM_ the month in year and _dd_ the day in the month. For instance, a valid value would be _\"2020-05-02\"_. <br /><br /> - **Date Time fields** should be in UTC following the ISO format _yyyy-MM-dd'T'HH:mm'Z'_. The date part follows the same date format, while _HH_ represents the hours (0-24), _mm_ the minutes in hour and _Z_ indicates the hour in UTC. For instance, a valid date time value would be _\"2020-05-02T10:30Z\"_. <br /><br /> The remaining field types values do not required a specific validation. For instance, for a Single Line Custom field a valid value would be _\"Perform Action B\"_. <br /><br /> If some value is not valid for a certain custom field type, an error will be return stating the field with the incorrect value. A field value can be deleted sending an empty value, such as _\"\"_ or _[]_, or by sending _null_. **It is not possible to delete the value of a required field.**

        :param test_key: Test Key (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param update_step_request_body: (required)
        :type update_step_request_body: UpdateStepRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_put_serialize(
            test_key=test_key,
            step_id=step_id,
            update_step_request_body=update_step_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateStepResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_test_test_key_steps_step_id_put_without_preload_content(
        self,
        test_key: Annotated[StrictStr, Field(description="Test Key")],
        step_id: Annotated[StrictInt, Field(description="The id of the test step")],
        update_step_request_body: UpdateStepRequestBody,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_test_test_key_steps_step_id_put

        Updates the values of an existing test step, given the test key and step id. The user can update the field values and the attachments of a step. The values should follow a specific format similar to the step creation. <br/><br/> - **Toggle Fields** values should be _\"true\"_, _\"false\"_, _\"0\"_ or _\"1\"_ <br /><br /> - **Number Fields** values should be a string containing a number, e.g. _\"320\"_. Decimal Number are also accepted,for instance, \"320.5\". The decimal places are always separated by a _\".\"_ <br /> <br /> - **Single Select and Radio Button Fields** values should be a single string containing the option value, e.g. _\"Option A\"_. The value should be a valid option for that custom field. The values are not case sensitive. <br /><br /> - **Multiple Select Fields** values should be an array of the string of option values, e.g. _[\"Option A\", \"Option B\"]_. All the selected values should be valid for that custom field. The option values are not case sensitive. <br /><br /> - **Date Fields** should follow the ISO format _yyyy-MM-dd_, where _yyyy_ represents the year, _MM_ the month in year and _dd_ the day in the month. For instance, a valid value would be _\"2020-05-02\"_. <br /><br /> - **Date Time fields** should be in UTC following the ISO format _yyyy-MM-dd'T'HH:mm'Z'_. The date part follows the same date format, while _HH_ represents the hours (0-24), _mm_ the minutes in hour and _Z_ indicates the hour in UTC. For instance, a valid date time value would be _\"2020-05-02T10:30Z\"_. <br /><br /> The remaining field types values do not required a specific validation. For instance, for a Single Line Custom field a valid value would be _\"Perform Action B\"_. <br /><br /> If some value is not valid for a certain custom field type, an error will be return stating the field with the incorrect value. A field value can be deleted sending an empty value, such as _\"\"_ or _[]_, or by sending _null_. **It is not possible to delete the value of a required field.**

        :param test_key: Test Key (required)
        :type test_key: str
        :param step_id: The id of the test step (required)
        :type step_id: int
        :param update_step_request_body: (required)
        :type update_step_request_body: UpdateStepRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_test_test_key_steps_step_id_put_serialize(
            test_key=test_key,
            step_id=step_id,
            update_step_request_body=update_step_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateStepResponse",
            '400': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_test_test_key_steps_step_id_put_serialize(
        self,
        test_key,
        step_id,
        update_step_request_body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if test_key is not None:
            _path_params['testKey'] = test_key
        if step_id is not None:
            _path_params['stepId'] = step_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if update_step_request_body is not None:
            _body_params = update_step_request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/1.0/api/test/{testKey}/steps/{stepId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, field_validator
from typing import Optional, Tuple, Union
from typing_extensions import Annotated
from openapi_client.models.rest_api_success_response import RestApiSuccessResponse
from openapi_client.models.xray_json_import_execution import XrayJsonImportExecution

from openapi_client.api_client import ApiClient, RequestSerialized
from openapi_client.api_response import ApiResponse
from openapi_client.rest import RESTResponseType


class ImportApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def post_import_execution(
        self,
        xray_json_import_execution: Optional[XrayJsonImportExecution] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RestApiSuccessResponse:
        """

        Endpoint used to import Test results in the Xray JSON format. <br></br> Updating an existing Test Run using Xray format REST API will reset all dataset related fields. This means that all current iteration data and dataset present in the Test Run will be replaced with the new information given in the REST API request.

        :param xray_json_import_execution:
        :type xray_json_import_execution: XrayJsonImportExecution
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_import_execution_serialize(
            xray_json_import_execution=xray_json_import_execution,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RestApiSuccessResponse",
            '400': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def post_import_execution_with_http_info(
        self,
        xray_json_import_execution: Optional[XrayJsonImportExecution] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RestApiSuccessResponse]:
        """

        Endpoint used to import Test results in the Xray JSON format. <br></br> Updating an existing Test Run using Xray format REST API will reset all dataset related fields. This means that all current iteration data and dataset present in the Test Run will be replaced with the new information given in the REST API request.

        :param xray_json_import_execution:
        :type xray_json_import_execution: XrayJsonImportExecution
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_import_execution_serialize(
            xray_json_import_execution=xray_json_import_execution,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RestApiSuccessResponse",
            '400': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def post_import_execution_without_preload_content(
        self,
        xray_json_import_execution: Optional[XrayJsonImportExecution] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """

        Endpoint used to import Test results in the Xray JSON format. <br></br> Updating an existing Test Run using Xray format REST API will reset all dataset related fields. This means that all current iteration data and dataset present in the Test Run will be replaced with the new information given in the REST API request.

        :param xray_json_import_execution:
        :type xray_json_import_execution: XrayJsonImportExecution
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_import_execution_serialize(
            xray_json_import_execution=xray_json_import_execution,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RestApiSuccessResponse",
            '400': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _post_import_execution_serialize(
        self,
        xray_json_import_execution,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if xray_json_import_execution is not None:
            _body_params = xray_json_import_execution


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/1.0/api/import/execution',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def post_import_execution_multipart(
        self,
        result: Annotated[Union[Annotated[bytes, Field(strict=True)], Annotated[str, Field(strict=True)], Tuple[str, Annotated[bytes, Field(strict=True)]]], Field(description="The Xray JSON file, same as described in the `POST /import/execution` ([link](https://docs.getxray.app/display/XRAY420/v2.0#/Import/post-import-execution)). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Create new Test Execution issue)</summary>  ``` {   \\\"info\\\": {     \\\"summary\\\": \\\"Execution of automated tests for release v1.3\\\",     \\\"description\\\": \\\"This execution is automatically created when importing execution results from an external source\\\",     \\\"version\\\": \\\"v1.3\\\",     \\\"user\\\": \\\"admin\\\",     \\\"revision\\\": \\\"1.0.42134\\\",     \\\"startDate\\\": \\\"2014-08-30T11:47:35+01:00\\\",     \\\"finishDate\\\": \\\"2014-08-30T11:53:00+01:00\\\",     \\\"testPlanKey\\\": \\\"DEMO-100\\\",     \\\"testEnvironments\\\": [       \\\"iOS\\\",       \\\"Android\\\"     ]   },   \\\"tests\\\": [     {       \\\"testKey\\\": \\\"DEMO-6\\\",       \\\"start\\\": \\\"2014-08-30T11:47:35+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:50:56+01:00\\\",       \\\"comment\\\": \\\"Successful execution\\\",       \\\"status\\\": \\\"PASS\\\"     },     {       \\\"testKey\\\": \\\"DEMO-7\\\",       \\\"start\\\": \\\"2014-08-30T11:51:00+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:52:30+01:00\\\",       \\\"comment\\\": \\\"Execution failed. Example #5 FAIL.\\\",       \\\"status\\\": \\\"FAIL\\\",       \\\"customFields\\\": [         {           \\\"id\\\": 321,           \\\"value\\\": [             \\\"option A\\\",             \\\"option B\\\"           ]         }       ],       \\\"evidences\\\": [         {           \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAEn(...base64 file enconding)\\\",           \\\"filename\\\": \\\"image21.jpg\\\",           \\\"contentType\\\": \\\"image/jpeg\\\"         }       ],       \\\"examples\\\": [         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"FAIL\\\"       ],       \\\"steps\\\": [         {           \\\"status\\\": \\\"PASS\\\",           \\\"comment\\\": \\\"Coment on Test Step Result 1\\\",           \\\"evidences\\\": [             {               \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAAEn(...base64 file enconding)\\\",               \\\"filename\\\": \\\"image22.jpg\\\",               \\\"contentType\\\": \\\"image/jpeg\\\"             }           ],           \\\"actualResult\\\": \\\"Actual result on Test Step 1\\\"         }       ],       \\\"defects\\\": [         \\\"DEMO-10\\\",         \\\"DEMO-11\\\"       ]     }   ] } ``` </details>  <details> <summary>Example 2 (Update Existing Test Execution)</summary>  ``` {     \\\"testExecutionKey\\\": \\\"DEMO-1206\\\",     \\\"tests\\\" : [         {             \\\"testKey\\\" : \\\"DEMO-6\\\",             \\\"start\\\" : \\\"2014-08-30T11:47:35+01:00\\\",             \\\"finish\\\" : \\\"2014-08-30T11:50:56+01:00\\\",             \\\"comment\\\" : \\\"Successful execution\\\",             \\\"status\\\" : \\\"PASS\\\"         }      ] } ``` </details>  ")],
        info: Annotated[Union[Annotated[bytes, Field(strict=True)], Annotated[str, Field(strict=True)], Tuple[str, Annotated[bytes, Field(strict=True)]]], Field(description="Should follow the same format as the \\\"fields\\\" part, described in the [official Jira REST API](https://docs.atlassian.com/software/jira/docs/api/REST/latest/#api/2/issue-createIssue). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Fields for a new Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"project\\\": {             \\\"id\\\": \\\"10402\\\"         },         \\\"summary\\\": \\\"Brand new Test execution\\\",         \\\"issuetype\\\": {             \\\"id\\\": \\\"10007\\\"         },         \\\"components\\\" : [             {             \\\"name\\\":\\\"Interface\\\"             },             {             \\\"name\\\":\\\"Core\\\"             }         ],         \\\"customfield_10032\\\" : [             \\\"TES-38\\\"         ]     } } ``` </details>  <details> <summary>Example 2 (Fields for updating a Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"customfield_10032\\\" : [             \\\"a_label\\\"         ],         \\\"description\\\": \\\"update the issue description\\\"     } } ```  </details>  ")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RestApiSuccessResponse:
        """

        Endpoint used to import Test results in the Xray JSON format with Test Execution issue data.  <br></br> Updating an existing Test Run using Xray format REST API will reset all dataset related fields. This means that all current iteration data and dataset present in the Test Run will be replaced with the new information given in the REST API request.

        :param result: The Xray JSON file, same as described in the `POST /import/execution` ([link](https://docs.getxray.app/display/XRAY420/v2.0#/Import/post-import-execution)). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Create new Test Execution issue)</summary>  ``` {   \\\"info\\\": {     \\\"summary\\\": \\\"Execution of automated tests for release v1.3\\\",     \\\"description\\\": \\\"This execution is automatically created when importing execution results from an external source\\\",     \\\"version\\\": \\\"v1.3\\\",     \\\"user\\\": \\\"admin\\\",     \\\"revision\\\": \\\"1.0.42134\\\",     \\\"startDate\\\": \\\"2014-08-30T11:47:35+01:00\\\",     \\\"finishDate\\\": \\\"2014-08-30T11:53:00+01:00\\\",     \\\"testPlanKey\\\": \\\"DEMO-100\\\",     \\\"testEnvironments\\\": [       \\\"iOS\\\",       \\\"Android\\\"     ]   },   \\\"tests\\\": [     {       \\\"testKey\\\": \\\"DEMO-6\\\",       \\\"start\\\": \\\"2014-08-30T11:47:35+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:50:56+01:00\\\",       \\\"comment\\\": \\\"Successful execution\\\",       \\\"status\\\": \\\"PASS\\\"     },     {       \\\"testKey\\\": \\\"DEMO-7\\\",       \\\"start\\\": \\\"2014-08-30T11:51:00+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:52:30+01:00\\\",       \\\"comment\\\": \\\"Execution failed. Example #5 FAIL.\\\",       \\\"status\\\": \\\"FAIL\\\",       \\\"customFields\\\": [         {           \\\"id\\\": 321,           \\\"value\\\": [             \\\"option A\\\",             \\\"option B\\\"           ]         }       ],       \\\"evidences\\\": [         {           \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAEn(...base64 file enconding)\\\",           \\\"filename\\\": \\\"image21.jpg\\\",           \\\"contentType\\\": \\\"image/jpeg\\\"         }       ],       \\\"examples\\\": [         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"FAIL\\\"       ],       \\\"steps\\\": [         {           \\\"status\\\": \\\"PASS\\\",           \\\"comment\\\": \\\"Coment on Test Step Result 1\\\",           \\\"evidences\\\": [             {               \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAAEn(...base64 file enconding)\\\",               \\\"filename\\\": \\\"image22.jpg\\\",               \\\"contentType\\\": \\\"image/jpeg\\\"             }           ],           \\\"actualResult\\\": \\\"Actual result on Test Step 1\\\"         }       ],       \\\"defects\\\": [         \\\"DEMO-10\\\",         \\\"DEMO-11\\\"       ]     }   ] } ``` </details>  <details> <summary>Example 2 (Update Existing Test Execution)</summary>  ``` {     \\\"testExecutionKey\\\": \\\"DEMO-1206\\\",     \\\"tests\\\" : [         {             \\\"testKey\\\" : \\\"DEMO-6\\\",             \\\"start\\\" : \\\"2014-08-30T11:47:35+01:00\\\",             \\\"finish\\\" : \\\"2014-08-30T11:50:56+01:00\\\",             \\\"comment\\\" : \\\"Successful execution\\\",             \\\"status\\\" : \\\"PASS\\\"         }      ] } ``` </details>   (required)
        :type result: bytearray
        :param info: Should follow the same format as the \\\"fields\\\" part, described in the [official Jira REST API](https://docs.atlassian.com/software/jira/docs/api/REST/latest/#api/2/issue-createIssue). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Fields for a new Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"project\\\": {             \\\"id\\\": \\\"10402\\\"         },         \\\"summary\\\": \\\"Brand new Test execution\\\",         \\\"issuetype\\\": {             \\\"id\\\": \\\"10007\\\"         },         \\\"components\\\" : [             {             \\\"name\\\":\\\"Interface\\\"             },             {             \\\"name\\\":\\\"Core\\\"             }         ],         \\\"customfield_10032\\\" : [             \\\"TES-38\\\"         ]     } } ``` </details>  <details> <summary>Example 2 (Fields for updating a Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"customfield_10032\\\" : [             \\\"a_label\\\"         ],         \\\"description\\\": \\\"update the issue description\\\"     } } ```  </details>   (required)
        :type info: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_import_execution_multipart_serialize(
            result=result,
            info=info,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RestApiSuccessResponse",
            '400': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def post_import_execution_multipart_with_http_info(
        self,
        result: Annotated[Union[Annotated[bytes, Field(strict=True)], Annotated[str, Field(strict=True)], Tuple[str, Annotated[bytes, Field(strict=True)]]], Field(description="The Xray JSON file, same as described in the `POST /import/execution` ([link](https://docs.getxray.app/display/XRAY420/v2.0#/Import/post-import-execution)). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Create new Test Execution issue)</summary>  ``` {   \\\"info\\\": {     \\\"summary\\\": \\\"Execution of automated tests for release v1.3\\\",     \\\"description\\\": \\\"This execution is automatically created when importing execution results from an external source\\\",     \\\"version\\\": \\\"v1.3\\\",     \\\"user\\\": \\\"admin\\\",     \\\"revision\\\": \\\"1.0.42134\\\",     \\\"startDate\\\": \\\"2014-08-30T11:47:35+01:00\\\",     \\\"finishDate\\\": \\\"2014-08-30T11:53:00+01:00\\\",     \\\"testPlanKey\\\": \\\"DEMO-100\\\",     \\\"testEnvironments\\\": [       \\\"iOS\\\",       \\\"Android\\\"     ]   },   \\\"tests\\\": [     {       \\\"testKey\\\": \\\"DEMO-6\\\",       \\\"start\\\": \\\"2014-08-30T11:47:35+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:50:56+01:00\\\",       \\\"comment\\\": \\\"Successful execution\\\",       \\\"status\\\": \\\"PASS\\\"     },     {       \\\"testKey\\\": \\\"DEMO-7\\\",       \\\"start\\\": \\\"2014-08-30T11:51:00+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:52:30+01:00\\\",       \\\"comment\\\": \\\"Execution failed. Example #5 FAIL.\\\",       \\\"status\\\": \\\"FAIL\\\",       \\\"customFields\\\": [         {           \\\"id\\\": 321,           \\\"value\\\": [             \\\"option A\\\",             \\\"option B\\\"           ]         }       ],       \\\"evidences\\\": [         {           \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAEn(...base64 file enconding)\\\",           \\\"filename\\\": \\\"image21.jpg\\\",           \\\"contentType\\\": \\\"image/jpeg\\\"         }       ],       \\\"examples\\\": [         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"FAIL\\\"       ],       \\\"steps\\\": [         {           \\\"status\\\": \\\"PASS\\\",           \\\"comment\\\": \\\"Coment on Test Step Result 1\\\",           \\\"evidences\\\": [             {               \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAAEn(...base64 file enconding)\\\",               \\\"filename\\\": \\\"image22.jpg\\\",               \\\"contentType\\\": \\\"image/jpeg\\\"             }           ],           \\\"actualResult\\\": \\\"Actual result on Test Step 1\\\"         }       ],       \\\"defects\\\": [         \\\"DEMO-10\\\",         \\\"DEMO-11\\\"       ]     }   ] } ``` </details>  <details> <summary>Example 2 (Update Existing Test Execution)</summary>  ``` {     \\\"testExecutionKey\\\": \\\"DEMO-1206\\\",     \\\"tests\\\" : [         {             \\\"testKey\\\" : \\\"DEMO-6\\\",             \\\"start\\\" : \\\"2014-08-30T11:47:35+01:00\\\",             \\\"finish\\\" : \\\"2014-08-30T11:50:56+01:00\\\",             \\\"comment\\\" : \\\"Successful execution\\\",             \\\"status\\\" : \\\"PASS\\\"         }      ] } ``` </details>  ")],
        info: Annotated[Union[Annotated[bytes, Field(strict=True)], Annotated[str, Field(strict=True)], Tuple[str, Annotated[bytes, Field(strict=True)]]], Field(description="Should follow the same format as the \\\"fields\\\" part, described in the [official Jira REST API](https://docs.atlassian.com/software/jira/docs/api/REST/latest/#api/2/issue-createIssue). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Fields for a new Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"project\\\": {             \\\"id\\\": \\\"10402\\\"         },         \\\"summary\\\": \\\"Brand new Test execution\\\",         \\\"issuetype\\\": {             \\\"id\\\": \\\"10007\\\"         },         \\\"components\\\" : [             {             \\\"name\\\":\\\"Interface\\\"             },             {             \\\"name\\\":\\\"Core\\\"             }         ],         \\\"customfield_10032\\\" : [             \\\"TES-38\\\"         ]     } } ``` </details>  <details> <summary>Example 2 (Fields for updating a Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"customfield_10032\\\" : [             \\\"a_label\\\"         ],         \\\"description\\\": \\\"update the issue description\\\"     } } ```  </details>  ")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RestApiSuccessResponse]:
        """

        Endpoint used to import Test results in the Xray JSON format with Test Execution issue data.  <br></br> Updating an existing Test Run using Xray format REST API will reset all dataset related fields. This means that all current iteration data and dataset present in the Test Run will be replaced with the new information given in the REST API request.

        :param result: The Xray JSON file, same as described in the `POST /import/execution` ([link](https://docs.getxray.app/display/XRAY420/v2.0#/Import/post-import-execution)). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Create new Test Execution issue)</summary>  ``` {   \\\"info\\\": {     \\\"summary\\\": \\\"Execution of automated tests for release v1.3\\\",     \\\"description\\\": \\\"This execution is automatically created when importing execution results from an external source\\\",     \\\"version\\\": \\\"v1.3\\\",     \\\"user\\\": \\\"admin\\\",     \\\"revision\\\": \\\"1.0.42134\\\",     \\\"startDate\\\": \\\"2014-08-30T11:47:35+01:00\\\",     \\\"finishDate\\\": \\\"2014-08-30T11:53:00+01:00\\\",     \\\"testPlanKey\\\": \\\"DEMO-100\\\",     \\\"testEnvironments\\\": [       \\\"iOS\\\",       \\\"Android\\\"     ]   },   \\\"tests\\\": [     {       \\\"testKey\\\": \\\"DEMO-6\\\",       \\\"start\\\": \\\"2014-08-30T11:47:35+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:50:56+01:00\\\",       \\\"comment\\\": \\\"Successful execution\\\",       \\\"status\\\": \\\"PASS\\\"     },     {       \\\"testKey\\\": \\\"DEMO-7\\\",       \\\"start\\\": \\\"2014-08-30T11:51:00+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:52:30+01:00\\\",       \\\"comment\\\": \\\"Execution failed. Example #5 FAIL.\\\",       \\\"status\\\": \\\"FAIL\\\",       \\\"customFields\\\": [         {           \\\"id\\\": 321,           \\\"value\\\": [             \\\"option A\\\",             \\\"option B\\\"           ]         }       ],       \\\"evidences\\\": [         {           \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAEn(...base64 file enconding)\\\",           \\\"filename\\\": \\\"image21.jpg\\\",           \\\"contentType\\\": \\\"image/jpeg\\\"         }       ],       \\\"examples\\\": [         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"FAIL\\\"       ],       \\\"steps\\\": [         {           \\\"status\\\": \\\"PASS\\\",           \\\"comment\\\": \\\"Coment on Test Step Result 1\\\",           \\\"evidences\\\": [             {               \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAAEn(...base64 file enconding)\\\",               \\\"filename\\\": \\\"image22.jpg\\\",               \\\"contentType\\\": \\\"image/jpeg\\\"             }           ],           \\\"actualResult\\\": \\\"Actual result on Test Step 1\\\"         }       ],       \\\"defects\\\": [         \\\"DEMO-10\\\",         \\\"DEMO-11\\\"       ]     }   ] } ``` </details>  <details> <summary>Example 2 (Update Existing Test Execution)</summary>  ``` {     \\\"testExecutionKey\\\": \\\"DEMO-1206\\\",     \\\"tests\\\" : [         {             \\\"testKey\\\" : \\\"DEMO-6\\\",             \\\"start\\\" : \\\"2014-08-30T11:47:35+01:00\\\",             \\\"finish\\\" : \\\"2014-08-30T11:50:56+01:00\\\",             \\\"comment\\\" : \\\"Successful execution\\\",             \\\"status\\\" : \\\"PASS\\\"         }      ] } ``` </details>   (required)
        :type result: bytearray
        :param info: Should follow the same format as the \\\"fields\\\" part, described in the [official Jira REST API](https://docs.atlassian.com/software/jira/docs/api/REST/latest/#api/2/issue-createIssue). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Fields for a new Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"project\\\": {             \\\"id\\\": \\\"10402\\\"         },         \\\"summary\\\": \\\"Brand new Test execution\\\",         \\\"issuetype\\\": {             \\\"id\\\": \\\"10007\\\"         },         \\\"components\\\" : [             {             \\\"name\\\":\\\"Interface\\\"             },             {             \\\"name\\\":\\\"Core\\\"             }         ],         \\\"customfield_10032\\\" : [             \\\"TES-38\\\"         ]     } } ``` </details>  <details> <summary>Example 2 (Fields for updating a Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"customfield_10032\\\" : [             \\\"a_label\\\"         ],         \\\"description\\\": \\\"update the issue description\\\"     } } ```  </details>   (required)
        :type info: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_import_execution_multipart_serialize(
            result=result,
            info=info,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RestApiSuccessResponse",
            '400': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def post_import_execution_multipart_without_preload_content(
        self,
        result: Annotated[Union[Annotated[bytes, Field(strict=True)], Annotated[str, Field(strict=True)], Tuple[str, Annotated[bytes, Field(strict=True)]]], Field(description="The Xray JSON file, same as described in the `POST /import/execution` ([link](https://docs.getxray.app/display/XRAY420/v2.0#/Import/post-import-execution)). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Create new Test Execution issue)</summary>  ``` {   \\\"info\\\": {     \\\"summary\\\": \\\"Execution of automated tests for release v1.3\\\",     \\\"description\\\": \\\"This execution is automatically created when importing execution results from an external source\\\",     \\\"version\\\": \\\"v1.3\\\",     \\\"user\\\": \\\"admin\\\",     \\\"revision\\\": \\\"1.0.42134\\\",     \\\"startDate\\\": \\\"2014-08-30T11:47:35+01:00\\\",     \\\"finishDate\\\": \\\"2014-08-30T11:53:00+01:00\\\",     \\\"testPlanKey\\\": \\\"DEMO-100\\\",     \\\"testEnvironments\\\": [       \\\"iOS\\\",       \\\"Android\\\"     ]   },   \\\"tests\\\": [     {       \\\"testKey\\\": \\\"DEMO-6\\\",       \\\"start\\\": \\\"2014-08-30T11:47:35+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:50:56+01:00\\\",       \\\"comment\\\": \\\"Successful execution\\\",       \\\"status\\\": \\\"PASS\\\"     },     {       \\\"testKey\\\": \\\"DEMO-7\\\",       \\\"start\\\": \\\"2014-08-30T11:51:00+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:52:30+01:00\\\",       \\\"comment\\\": \\\"Execution failed. Example #5 FAIL.\\\",       \\\"status\\\": \\\"FAIL\\\",       \\\"customFields\\\": [         {           \\\"id\\\": 321,           \\\"value\\\": [             \\\"option A\\\",             \\\"option B\\\"           ]         }       ],       \\\"evidences\\\": [         {           \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAEn(...base64 file enconding)\\\",           \\\"filename\\\": \\\"image21.jpg\\\",           \\\"contentType\\\": \\\"image/jpeg\\\"         }       ],       \\\"examples\\\": [         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"FAIL\\\"       ],       \\\"steps\\\": [         {           \\\"status\\\": \\\"PASS\\\",           \\\"comment\\\": \\\"Coment on Test Step Result 1\\\",           \\\"evidences\\\": [             {               \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAAEn(...base64 file enconding)\\\",               \\\"filename\\\": \\\"image22.jpg\\\",               \\\"contentType\\\": \\\"image/jpeg\\\"             }           ],           \\\"actualResult\\\": \\\"Actual result on Test Step 1\\\"         }       ],       \\\"defects\\\": [         \\\"DEMO-10\\\",         \\\"DEMO-11\\\"       ]     }   ] } ``` </details>  <details> <summary>Example 2 (Update Existing Test Execution)</summary>  ``` {     \\\"testExecutionKey\\\": \\\"DEMO-1206\\\",     \\\"tests\\\" : [         {             \\\"testKey\\\" : \\\"DEMO-6\\\",             \\\"start\\\" : \\\"2014-08-30T11:47:35+01:00\\\",             \\\"finish\\\" : \\\"2014-08-30T11:50:56+01:00\\\",             \\\"comment\\\" : \\\"Successful execution\\\",             \\\"status\\\" : \\\"PASS\\\"         }      ] } ``` </details>  ")],
        info: Annotated[Union[Annotated[bytes, Field(strict=True)], Annotated[str, Field(strict=True)], Tuple[str, Annotated[bytes, Field(strict=True)]]], Field(description="Should follow the same format as the \\\"fields\\\" part, described in the [official Jira REST API](https://docs.atlassian.com/software/jira/docs/api/REST/latest/#api/2/issue-createIssue). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Fields for a new Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"project\\\": {             \\\"id\\\": \\\"10402\\\"         },         \\\"summary\\\": \\\"Brand new Test execution\\\",         \\\"issuetype\\\": {             \\\"id\\\": \\\"10007\\\"         },         \\\"components\\\" : [             {             \\\"name\\\":\\\"Interface\\\"             },             {             \\\"name\\\":\\\"Core\\\"             }         ],         \\\"customfield_10032\\\" : [             \\\"TES-38\\\"         ]     } } ``` </details>  <details> <summary>Example 2 (Fields for updating a Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"customfield_10032\\\" : [             \\\"a_label\\\"         ],         \\\"description\\\": \\\"update the issue description\\\"     } } ```  </details>  ")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """

        Endpoint used to import Test results in the Xray JSON format with Test Execution issue data.  <br></br> Updating an existing Test Run using Xray format REST API will reset all dataset related fields. This means that all current iteration data and dataset present in the Test Run will be replaced with the new information given in the REST API request.

        :param result: The Xray JSON file, same as described in the `POST /import/execution` ([link](https://docs.getxray.app/display/XRAY420/v2.0#/Import/post-import-execution)). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Create new Test Execution issue)</summary>  ``` {   \\\"info\\\": {     \\\"summary\\\": \\\"Execution of automated tests for release v1.3\\\",     \\\"description\\\": \\\"This execution is automatically created when importing execution results from an external source\\\",     \\\"version\\\": \\\"v1.3\\\",     \\\"user\\\": \\\"admin\\\",     \\\"revision\\\": \\\"1.0.42134\\\",     \\\"startDate\\\": \\\"2014-08-30T11:47:35+01:00\\\",     \\\"finishDate\\\": \\\"2014-08-30T11:53:00+01:00\\\",     \\\"testPlanKey\\\": \\\"DEMO-100\\\",     \\\"testEnvironments\\\": [       \\\"iOS\\\",       \\\"Android\\\"     ]   },   \\\"tests\\\": [     {       \\\"testKey\\\": \\\"DEMO-6\\\",       \\\"start\\\": \\\"2014-08-30T11:47:35+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:50:56+01:00\\\",       \\\"comment\\\": \\\"Successful execution\\\",       \\\"status\\\": \\\"PASS\\\"     },     {       \\\"testKey\\\": \\\"DEMO-7\\\",       \\\"start\\\": \\\"2014-08-30T11:51:00+01:00\\\",       \\\"finish\\\": \\\"2014-08-30T11:52:30+01:00\\\",       \\\"comment\\\": \\\"Execution failed. Example #5 FAIL.\\\",       \\\"status\\\": \\\"FAIL\\\",       \\\"customFields\\\": [         {           \\\"id\\\": 321,           \\\"value\\\": [             \\\"option A\\\",             \\\"option B\\\"           ]         }       ],       \\\"evidences\\\": [         {           \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAEn(...base64 file enconding)\\\",           \\\"filename\\\": \\\"image21.jpg\\\",           \\\"contentType\\\": \\\"image/jpeg\\\"         }       ],       \\\"examples\\\": [         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"PASS\\\",         \\\"FAIL\\\"       ],       \\\"steps\\\": [         {           \\\"status\\\": \\\"PASS\\\",           \\\"comment\\\": \\\"Coment on Test Step Result 1\\\",           \\\"evidences\\\": [             {               \\\"data\\\": \\\"iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAAEn(...base64 file enconding)\\\",               \\\"filename\\\": \\\"image22.jpg\\\",               \\\"contentType\\\": \\\"image/jpeg\\\"             }           ],           \\\"actualResult\\\": \\\"Actual result on Test Step 1\\\"         }       ],       \\\"defects\\\": [         \\\"DEMO-10\\\",         \\\"DEMO-11\\\"       ]     }   ] } ``` </details>  <details> <summary>Example 2 (Update Existing Test Execution)</summary>  ``` {     \\\"testExecutionKey\\\": \\\"DEMO-1206\\\",     \\\"tests\\\" : [         {             \\\"testKey\\\" : \\\"DEMO-6\\\",             \\\"start\\\" : \\\"2014-08-30T11:47:35+01:00\\\",             \\\"finish\\\" : \\\"2014-08-30T11:50:56+01:00\\\",             \\\"comment\\\" : \\\"Successful execution\\\",             \\\"status\\\" : \\\"PASS\\\"         }      ] } ``` </details>   (required)
        :type result: bytearray
        :param info: Should follow the same format as the \\\"fields\\\" part, described in the [official Jira REST API](https://docs.atlassian.com/software/jira/docs/api/REST/latest/#api/2/issue-createIssue). This file **must** be of type `application/json`.  <details> <summary>Example 1 (Fields for a new Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"project\\\": {             \\\"id\\\": \\\"10402\\\"         },         \\\"summary\\\": \\\"Brand new Test execution\\\",         \\\"issuetype\\\": {             \\\"id\\\": \\\"10007\\\"         },         \\\"components\\\" : [             {             \\\"name\\\":\\\"Interface\\\"             },             {             \\\"name\\\":\\\"Core\\\"             }         ],         \\\"customfield_10032\\\" : [             \\\"TES-38\\\"         ]     } } ``` </details>  <details> <summary>Example 2 (Fields for updating a Test Execution)</summary>  ``` {     \\\"fields\\\": {         \\\"customfield_10032\\\" : [             \\\"a_label\\\"         ],         \\\"description\\\": \\\"update the issue description\\\"     } } ```  </details>   (required)
        :type info: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_import_execution_multipart_serialize(
            result=result,
            info=info,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RestApiSuccessResponse",
            '400': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _post_import_execution_multipart_serialize(
        self,
        result,
        info,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if result is not None:
            _files['result'] = result
        if info is not None:
            _files['info'] = info
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/1.0/api/import/execution/multipart',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.test_run_response import TestRunResponse

class TestTestRunResponse(unittest.TestCase):
    """TestRunResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestRunResponse:
        """Test TestRunResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestRunResponse`
        """
        model = TestRunResponse()
        if include_optional:
            return TestRunResponse(
                id = 1004725,
                status = 'FAIL',
                color = '#D45D52',
                test_key = 'CALC-67187',
                test_exec_key = 'CALC-67193',
                test_version = 'manual_1',
                assignee = 'admin',
                executed_by = 'admin',
                started_on = '2020-02-12T09:58:04Z',
                finished_on = '2020-02-12T10:58:04Z',
                started_on_iso = '2020-02-12T09:58:04Z',
                finished_on_iso = '2020-02-12T10:58:04Z',
                duration = 1923493000,
                defects = ["CALC-1","CALC-2"],
                evidences = [
                    {"id":25684,"fileName":"attachment.txt","fileIcon":"text.gif","mimeType":"plain/text","fileIconAlt":"Text File","fileSize":"100.0 kB","numericalFileSize":"12","created":"2020-02-06T10:39:37Z","createdDate":1580985577000,"author":"admin","authorFullName":"Bruce Wayne","fileURL":"http://example.com/attachment/25684/example2.txt","filePath":"/Users/example/path/attachment"}
                    ],
                comment = 'Test Run comment',
                test_environments = ["iOS","Android"],
                fix_versions = [
                    openapi_client.models.version.Version(
                        id = '97845', 
                        name = '1.0', 
                        description = 'Version 1.0', 
                        is_archived = True, 
                        is_released = False, )
                    ],
                custom_fields = [
                    null
                    ],
                steps = [
                    openapi_client.models.step_result.StepResult(
                        id = 85778, 
                        index = 1, 
                        fields = {"Action":{"type":"Wiki","value":{"raw":"This is a step action","rendered":"<p>This is a step action</p>"}},"Toggle":{"type":"Data","value":"false"}}, 
                        attachments = [
                            {"id":25684,"fileName":"attachment.txt","fileIcon":"text.gif","mimeType":"plain/text","fileIconAlt":"Text File","fileSize":"100.0 kB","numericalFileSize":"12","created":"2020-02-06T10:39:37Z","createdDate":1580985577000,"author":"admin","authorFullName":"Bruce Wayne","fileURL":"http://example.com/attachment/25684/example2.txt","filePath":"/Users/example/path/attachment"}
                            ], 
                        status = 'PASS', 
                        comment = openapi_client.models.step_result_comment.StepResult_comment(
                            rendered = 'Comment on step', ), 
                        defects = ["CALC-123","CALC-765"], 
                        evidences = [
                            {"id":25684,"fileName":"attachment.txt","fileIcon":"text.gif","mimeType":"plain/text","fileIconAlt":"Text File","fileSize":"100.0 kB","numericalFileSize":"12","created":"2020-02-06T10:39:37Z","createdDate":1580985577000,"author":"admin","authorFullName":"Bruce Wayne","fileURL":"http://example.com/attachment/25684/example2.txt","filePath":"/Users/example/path/attachment"}
                            ], 
                        actual_result = openapi_client.models.step_result_actual_result.StepResult_actualResult(
                            rendered = 'Actual result on step', ), )
                    ],
                iterations = [
                    openapi_client.models.test_run_iteration_status_information.TestRunIterationStatusInformation(
                        id = 56, 
                        status = '', 
                        color = '', 
                        parameters = [
                            openapi_client.models.dataset_parameter.DatasetParameter(
                                name = '', 
                                value = '', )
                            ], )
                    ],
                parameters = [
                    openapi_client.models.dataset_parameter.DatasetParameter(
                        name = '', 
                        value = '', )
                    ]
            )
        else:
            return TestRunResponse(
        )
        """

    def testTestRunResponse(self):
        """Test TestRunResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
